@@ -17,7 +17,6 @@ import contextlib
 import socket
 
 import mock
-from mock import patch
 import netifaces
 from oslotest import base as test_base
 import six
@@ -261,7 +260,7 @@ class NetworkUtilsTest(test_base.BaseTestCase):
     @mock.patch('netifaces.ifaddresses')
     def test_get_my_ipv4_address_with_default_route(
             self, ifaddr, gateways):
-        with patch.dict(netifaces.__dict__, {'AF_INET': '0'}):
+        with mock.patch.dict(netifaces.__dict__, {'AF_INET': '0'}):
             ifaddr.return_value = {'0': [{'addr': '172.18.204.1'}]}
             addr = netutils._get_my_ipv4_address()
         self.assertEqual('172.18.204.1', addr)
@@ -270,7 +269,7 @@ class NetworkUtilsTest(test_base.BaseTestCase):
     @mock.patch('netifaces.ifaddresses')
     def test_get_my_ipv4_address_without_default_route(
             self, ifaddr, gateways):
-        with patch.dict(netifaces.__dict__, {'AF_INET': '0'}):
+        with mock.patch.dict(netifaces.__dict__, {'AF_INET': '0'}):
             ifaddr.return_value = {}
             addr = netutils._get_my_ipv4_address()
         self.assertEqual('127.0.0.1', addr)
@@ -317,6 +316,12 @@ class IPv6byEUI64TestCase(test_base.BaseTestCase):
         self.assertRaises(TypeError, lambda:
                           netutils.get_ipv6_addr_by_EUI64(prefix, mac))
 
+    def test_generate_IPv6_with_empty_prefix(self):
+        mac = '00:16:3e:33:44:55'
+        prefix = ''
+        self.assertRaises(ValueError, lambda:
+                          netutils.get_ipv6_addr_by_EUI64(prefix, mac))
+
 
 @contextlib.contextmanager
 def mock_file_content(content):
